@@ -128,46 +128,8 @@ class GetDependenciesPlugin(plugin.ArtellaPlugin, object):
                     if not file_status or not file_status[0]:
                         continue
                     files_to_download.append(pth)
-        artella_drive_client.download(files_to_download)
 
-        # We force the waiting to a high value, otherwise Artella Drive Client will return that no download
-        # is being processed
-        time.sleep(1.0)
-
-        valid_download = True
-        if show_dialogs:
-            if qtutils.QT_AVAILABLE:
-                dcc_progress_bar = splash.ProgressSplashDialog()
-            else:
-                dcc_progress_bar = artella.ProgressBar()
-
-            dcc_progress_bar.start()
-        while True:
-            if show_dialogs and dcc_progress_bar.is_cancelled():
-                artella_drive_client.pause_downloads()
-                valid_download = False
-                break
-            progress, fd, ft, bd, bt = artella_drive_client.get_progress()
-            progress_status = '{} of {} KiB downloaded\n{} of {} files downloaded'.format(
-                int(bd / 1024), int(bt / 1024), fd, ft)
-            if show_dialogs:
-                dcc_progress_bar.set_progress_value(value=progress, status=progress_status)
-            if progress >= 100 or bd == bt:
-                break
-
-        total_checks = 0
-        if valid_download:
-            missing_file = False
-            for local_file_path in files_to_download:
-                if not os.path.exists(local_file_path):
-                    missing_file = True
-                    break
-            while missing_file and total_checks < 5:
-                time.sleep(1.0)
-                total_checks += 1
-
-        if show_dialogs:
-            dcc_progress_bar.end()
+        self._download_files(files_to_download, show_dialogs=show_dialogs)
 
         if update_paths:
             files_to_update = list(set(files_to_update))
@@ -207,14 +169,63 @@ class GetDependenciesPlugin(plugin.ArtellaPlugin, object):
             return non_available_deps
 
         parser = artella.Parser()
-        deps_file_paths = parser.parse(file_path) or list()
+        deps_file_paths = parser.parse(file_path, show_dialogs=False) or list()
+
         if not deps_file_paths:
             return non_available_deps
 
+        remote_path_files = dict()
+
         for dep_file_path in deps_file_paths:
-            translated_path = artella.DccPlugin().translate_path(dep_file_path)
-            if translated_path and not os.path.isfile(translated_path):
-                non_available_deps.append(translated_path)
+            if dcc.is_udim_path(dep_file_path):
+                folder_directory = os.path.dirname(dep_file_path)
+                dep_file_name, dep_file_ext = os.path.splitext(os.path.basename(dep_file_path))
+                dep_file_parts = dep_file_name.split('_')
+                if folder_directory not in remote_path_files:
+                    directory_info = artella_drive_client.status(folder_directory, include_remote=True) or None
+                    if not directory_info:
+                        remote_path_files[folder_directory] = list()
+                    else:
+                        directory_info = directory_info[0]
+                        for handle, data in directory_info.items():
+                            remote_info = data.get('remote_info', dict())
+                            remote_path_files.setdefault(folder_directory, list())
+                            is_file = remote_info.get('raw', dict()).get('type', None) == 'file'
+                            name = remote_info.get('name', None)
+                            if is_file and name:
+                                remote_path_files[folder_directory].append(name)
+                if folder_directory in remote_path_files:
+                    for directory_path, file_names in remote_path_files.items():
+                        if not file_names:
+                            continue
+                        for file_name in file_names:
+                            valid = True
+                            file_parts = file_name.split('_')
+                            for dep_part, file_part in zip(dep_file_parts, file_parts):
+                                if dep_part == '<UDIM>':
+                                    continue
+                                if dep_part != file_part:
+                                    valid = False
+                                    break
+                            if valid:
+                                udim_file_path = os.path.join(directory_path, file_name)
+                                translated_path = artella.DccPlugin().translate_path(udim_file_path)
+                                if translated_path and not os.path.isfile(translated_path):
+                                    if os.path.isdir(translated_path):
+                                        continue
+                                    file_ext = os.path.splitext(translated_path)
+                                    if not file_ext[-1]:
+                                        continue
+                                    non_available_deps.append(translated_path)
+            else:
+                translated_path = artella.DccPlugin().translate_path(dep_file_path)
+                if translated_path and not os.path.isfile(translated_path):
+                    if os.path.isdir(translated_path):
+                        continue
+                    file_ext = os.path.splitext(translated_path)
+                    if not file_ext[-1]:
+                        continue
+                    non_available_deps.append(translated_path)
 
         deps_retrieved = list()
         if non_available_deps:
@@ -225,12 +236,18 @@ class GetDependenciesPlugin(plugin.ArtellaPlugin, object):
             if show_dialogs:
                 get_deps, recursive = self._show_get_deps_dialog(deps=non_available_deps)
             if get_deps:
-                for non_available_dep in non_available_deps:
-                    deps = self.get_dependencies(
-                        non_available_dep, recursive=recursive, update_paths=False, show_dialogs=show_dialogs)
-                    if deps:
-                        deps_retrieved.append(deps)
-                    else:
+                if recursive:
+                    for non_available_dep in non_available_deps:
+                        deps = self.get_dependencies(
+                            non_available_dep, recursive=recursive, update_paths=False, show_dialogs=show_dialogs)
+                        if deps:
+                            deps_retrieved.append(deps)
+                        else:
+                            deps_retrieved.append({non_available_dep: []})
+                else:
+                    deps_retrieved = list()
+                    self._download_files(non_available_deps, show_dialogs=show_dialogs)
+                    for non_available_dep in non_available_deps:
                         deps_retrieved.append({non_available_dep: []})
 
         if show_dialogs:
@@ -272,6 +289,53 @@ class GetDependenciesPlugin(plugin.ArtellaPlugin, object):
                     deps_dialog.add_dependency(dep_parent_path, None)
         deps_dialog.show()
 
+    def _download_files(self, files_to_download, show_dialogs=True):
+
+        artella_drive_client = artella.DccPlugin().get_client()
+        if not artella_drive_client or not artella_drive_client.check(update=True):
+            return
+
+        artella_drive_client.download(files_to_download)
+
+        # We force the waiting to a high value, otherwise Artella Drive Client will return that no download
+        # is being processed
+        time.sleep(1.0)
+
+        valid_download = True
+        if show_dialogs:
+            if qtutils.QT_AVAILABLE:
+                dcc_progress_bar = splash.ProgressSplashDialog()
+            else:
+                dcc_progress_bar = artella.ProgressBar()
+
+            dcc_progress_bar.start()
+        while True:
+            if show_dialogs and dcc_progress_bar.is_cancelled():
+                artella_drive_client.pause_downloads()
+                valid_download = False
+                break
+            progress, fd, ft, bd, bt = artella_drive_client.get_progress()
+            progress_status = '{} of {} KiB downloaded\n{} of {} files downloaded'.format(
+                int(bd / 1024), int(bt / 1024), fd, ft)
+            if show_dialogs:
+                dcc_progress_bar.set_progress_value(value=progress, status=progress_status)
+            if progress >= 100 or bd == bt:
+                break
+
+        total_checks = 0
+        if valid_download:
+            missing_file = False
+            for local_file_path in files_to_download:
+                if not os.path.exists(local_file_path):
+                    missing_file = True
+                    break
+            while missing_file and total_checks < 5:
+                time.sleep(1.0)
+                total_checks += 1
+
+        if show_dialogs:
+            dcc_progress_bar.end()
+
     def _post_get_dependencies(self, **kwargs):
         """
         Internal function that is called after get dependencies functionality is over. Can be override in custom DCC
